==> message-facade-2.0.2-20210908.054910-93-sources.jar: com/bizvane/messagefacade/models/vo/MsgTemplateSendConfigVO.java <==
package com.bizvane.messagefacade.models.vo;

import io.swagger.annotations.ApiModelProperty;

import java.util.Date;

public class MsgTemplateSendConfigVO {
    /**
     * id
     * @mbg.generated Fri Jul 30 19:54:07 CST 2021
     */
    @ApiModelProperty(value = "id", name = "id", required = false, example = "")
    private Long id;

    /**
     * 企业id
     */
    @ApiModelProperty(value = "企业id", name = "sysCompanyId", required = false, example = "")
    private Long sysCompanyId;

    /**
     * 品牌id
     */
    @ApiModelProperty(value = "品牌id", name = "sysBrandId", required = false, example = "")
    private Long sysBrandId;

    /**
     * 模板类型
     */
    @ApiModelProperty(value = "模板类型", name = "templateType", required = false, example = "")
    private String templateType;

    /**
     * 配置内容 {"expirePoint":过期积分,"absPoint":积分绝对值}
     */
    @ApiModelProperty(value = "配置内容 {'expirePoint':过期积分,'absPoint':积分绝对值}", name = "content", required = false, example = "")
    private String content;

    /**
     * 修改人id
     */
    @ApiModelProperty(value = "修改人id", name = "modifiedUserId", required = false, example = "")
    private Long modifiedUserId;

    /**
     * 修改人名称
     */
    @ApiModelProperty(value = "修改人名称", name = "modifiedUserName", required = false, example = "")
    private String modifiedUserName;

    /**
     * 修改时间
     */
    @ApiModelProperty(value = "修改时间", name = "modifiedDate", required = false, example = "")
    private Date modifiedDate;

    /**
     * 创建人id
     */
    @ApiModelProperty(value = "创建人id", name = "createUserId", required = false, example = "")
    private Long createUserId;

    /**
     * 创建人名称
     */
    @ApiModelProperty(value = "创建人名称", name = "createUserName", required = false, example = "")
    private String createUserName;

    /**
     * 创建时间
     */
    @ApiModelProperty(value = "创建时间", name = "createDate", required = false, example = "")
    private Date createDate;

    /**
     * 是否有效 0-无效 1-有效
     */
    @ApiModelProperty(value = "是否有效 0-无效 1-有效", name = "valid", required = false, example = "")
    private Boolean valid;

    @ApiModelProperty(value = "页码", name = "pageNumber", required = false, example = "")
    private Integer pageNumber;

    @ApiModelProperty(value = "步距", name = "pageSize", required = false, example = "")
    private Integer pageSize;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public String getTemplateType() {
        return templateType;
    }

    public void setTemplateType(String templateType) {
        this.templateType = templateType == null ? null : templateType.trim();
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content == null ? null : content.trim();
    }

    public Long getModifiedUserId() {
        return modifiedUserId;
    }

    public void setModifiedUserId(Long modifiedUserId) {
        this.modifiedUserId = modifiedUserId;
    }

    public String getModifiedUserName() {
        return modifiedUserName;
    }

    public void setModifiedUserName(String modifiedUserName) {
        this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
    }

    public Date getModifiedDate() {
        return modifiedDate;
    }

    public void setModifiedDate(Date modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName == null ? null : createUserName.trim();
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Boolean getValid() {
        return valid;
    }

    public void setValid(Boolean valid) {
        this.valid = valid;
    }

    public Integer getPageNumber() {
        return pageNumber;
    }

    public void setPageNumber(Integer pageNumber) {
        this.pageNumber = pageNumber;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }
}

==> message-facade-2.0.12-20250805.051308-2-sources.jar: com/bizvane/messagefacade/models/vo/MsgTemplateSendConfigVO.java <==
package com.bizvane.messagefacade.models.vo;

import io.swagger.annotations.ApiModelProperty;

import java.util.Date;

public class MsgTemplateSendConfigVO {
    /**
     * id
     * @mbg.generated Fri Jul 30 19:54:07 CST 2021
     */
    @ApiModelProperty(value = "id", name = "id", required = false, example = "")
    private Long id;

    /**
     * 企业id
     */
    @ApiModelProperty(value = "企业id", name = "sysCompanyId", required = false, example = "")
    private Long sysCompanyId;

    /**
     * 品牌id
     */
    @ApiModelProperty(value = "品牌id", name = "sysBrandId", required = false, example = "")
    private Long sysBrandId;

    /**
     * 模板类型
     */
    @ApiModelProperty(value = "模板类型", name = "templateType", required = false, example = "")
    private String templateType;

    /**
     * 配置内容 {"expirePoint":过期积分,"absPoint":积分绝对值}
     */
    @ApiModelProperty(value = "配置内容 {'expirePoint':过期积分,'absPoint':积分绝对值}", name = "content", required = false, example = "")
    private String content;

    /**
     * 修改人id
     */
    @ApiModelProperty(value = "修改人id", name = "modifiedUserId", required = false, example = "")
    private Long modifiedUserId;

    /**
     * 修改人名称
     */
    @ApiModelProperty(value = "修改人名称", name = "modifiedUserName", required = false, example = "")
    private String modifiedUserName;

    /**
     * 修改时间
     */
    @ApiModelProperty(value = "修改时间", name = "modifiedDate", required = false, example = "")
    private Date modifiedDate;

    /**
     * 创建人id
     */
    @ApiModelProperty(value = "创建人id", name = "createUserId", required = false, example = "")
    private Long createUserId;

    /**
     * 创建人名称
     */
    @ApiModelProperty(value = "创建人名称", name = "createUserName", required = false, example = "")
    private String createUserName;

    /**
     * 创建时间
     */
    @ApiModelProperty(value = "创建时间", name = "createDate", required = false, example = "")
    private Date createDate;

    /**
     * 是否有效 0-无效 1-有效
     */
    @ApiModelProperty(value = "是否有效 0-无效 1-有效", name = "valid", required = false, example = "")
    private Boolean valid;
    /**
     * 短信发送开放日期（每月发送）
     */
    @ApiModelProperty(value = "短信发送开放日期（每月发送）", name = "openDate", required = false, example = "")
    private String openDate;

    @ApiModelProperty(value = "页码", name = "pageNumber", required = false, example = "")
    private Integer pageNumber;

    @ApiModelProperty(value = "步距", name = "pageSize", required = false, example = "")
    private Integer pageSize;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public String getTemplateType() {
        return templateType;
    }

    public void setTemplateType(String templateType) {
        this.templateType = templateType == null ? null : templateType.trim();
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content == null ? null : content.trim();
    }

    public Long getModifiedUserId() {
        return modifiedUserId;
    }

    public void setModifiedUserId(Long modifiedUserId) {
        this.modifiedUserId = modifiedUserId;
    }

    public String getModifiedUserName() {
        return modifiedUserName;
    }

    public void setModifiedUserName(String modifiedUserName) {
        this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
    }

    public Date getModifiedDate() {
        return modifiedDate;
    }

    public void setModifiedDate(Date modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName == null ? null : createUserName.trim();
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Boolean getValid() {
        return valid;
    }

    public void setValid(Boolean valid) {
        this.valid = valid;
    }

    public String getOpenDate() {
        return openDate;
    }

    public void setOpenDate(String openDate) {
        this.openDate = openDate;
    }

    public Integer getPageNumber() {
        return pageNumber;
    }

    public void setPageNumber(Integer pageNumber) {
        this.pageNumber = pageNumber;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }
}
